ajdmom.mdl\_2fsvj.cmom
======================

.. automodule:: ajdmom.mdl_2fsvj.cmom

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      cm
      cmoment_y
      dcm
      dpoly
      poly2num
   
   

   
   
   

   
   
   



